function [optf, optd, optb, optL] = identify_villain(X, n, M)
%
% Restart EM N times. EM will be randomly initialized and may converge
% to a local maximum of the likelihood function. Store the best
% estimate of the parameters as measured by the likelihood score and
% return those estimates after EM runs N times.
%
% Input parameters:
%
%   X  H x W x N matrix, M images that contain the villain
%   n  n <= N is the number of images that should be used to esimtate
%      the face of the villain (and other unknown parameters)
%   M  the number of iterations to restart EM
%
% Output parameters:
%
%   optf the best-so-far face 
%   optd the best-so-far displacements in each image
%   optb the best-so-far  estimate of the background
%   optL the best-so-far likelihood score

rng(314159);
optL = -Inf;
for i = 1:N
    [f,d,b,L] = run_EM(X,m);
    if L > optL
        optf = f;
        optd = d;
        optb = b;
        optL = l;
    end
end
